@@ -177,7 +177,7 @@ class ExceptionReporter:
         return t.render(**c)
 
     def get_lambda_response(self):
-        response = Response(self.get_traceback_html(), mimetype='text/html')
+        response = Response(self.get_traceback_html(), mimetype='text/html', status='500')
         headers = {}
         for key, value in response.headers:
             if key in headers:
@@ -391,12 +391,11 @@ class ExceptionHandler:
         return self.__reporter.get_lambda_response()
 
 
-def handle_exceptions(function=None, is_lambda: bool = False, return_html: bool = False,
+def handle_exceptions(is_lambda: bool = False, return_html: bool = False,
                       exceptions_folder: str = None, exclude: str = None, only_last: bool = True):
     """Organize and coordinate reporting on exceptions.
 
     Args:
-        function
         is_lambda (bool, optional): Set true if you want to handle lambda function. Defaults to False.
         return_html (bool, optional): Set true if you want the function to return html. Defaults to False.
         exceptions_folder (str, optional): Sets the exceptions folder. Defaults to None.
@@ -407,37 +406,39 @@ def handle_exceptions(function=None, is_lambda: bool = False, return_html: bool
         OSError: If file was not written correctly this error will raise
     """
 
-    def wrapper(*args, **kwargs):
-        try:
-            return function(*args, **kwargs)
-        except Exception:  # noqa
-            if is_lambda:
-                return ExceptionHandler(exclude=exclude).get_traceback_lambda()
-            elif return_html:
-                return ExceptionHandler(exclude=exclude).get_traceback_html()
-            else:
-                return save_exception(ExceptionHandler(exclude=exclude).get_traceback_html(), exceptions_folder)
+    def decorator(function):
+        def wrapper(*args, **kwargs):
+            try:
+                return function(*args, **kwargs)
+            except Exception:  # noqa
+                if is_lambda:
+                    return ExceptionHandler(exclude=exclude).get_traceback_lambda()
+                elif return_html:
+                    return ExceptionHandler(exclude=exclude).get_traceback_html()
+                else:
+                    time_string = datetime.now().strftime(r"%d-%m-%Y_%H-%M-%S")
+                    file_name = f'handled_exception_{time_string}.html'
+                    folder = exceptions_folder
+                    if folder is None:
+                        folder = os.path.dirname(os.path.abspath(__file__))  # noqa
+                        folder = os.path.join(folder, 'handled_exceptions')  # noqa
+                    Path(folder).mkdir(parents=True, exist_ok=True)
+                    if only_last:
+                        files_in_directory = os.listdir(folder)
+                        filtered_files = [file for file in files_in_directory if file.endswith(".html")]
+                        for file in filtered_files:
+                            path_to_file = os.path.join(folder, file)
+                            os.remove(path_to_file)
+                    file_path = os.path.join(folder, file_name)
+                    html = ExceptionHandler(exclude=exclude).get_traceback_html()
+                    try:
+                        with open(file_path, "w") as f:
+                            f.write(html)
+                        logging.warning(f'Handled exception: \nfile://{file_path}')
+                    except Exception as e:
+                        raise OSError('Failed to save file while handling exception: \n' + str(e))
+                    return None
 
-    def save_exception(html, exceptions_folder):  # noqa
-        time_string = datetime.now().strftime(r"%d-%m-%Y_%H-%M-%S")
-        file_name = f'handled_exception_{time_string}.html'
-        if exceptions_folder is None:
-            exceptions_folder = os.path.dirname(os.path.abspath(__file__))  # noqa
-            exceptions_folder = os.path.join(exceptions_folder, 'handled_exceptions')  # noqa
-        Path(exceptions_folder).mkdir(parents=True, exist_ok=True)
-        if only_last:
-            files_in_directory = os.listdir(exceptions_folder)
-            filtered_files = [file for file in files_in_directory if file.endswith(".html")]
-            for file in filtered_files:
-                path_to_file = os.path.join(exceptions_folder, file)
-                os.remove(path_to_file)
-        file_path = os.path.join(exceptions_folder, file_name)
-        try:
-            with open(file_path, "w") as f:
-                f.write(html)
-            logging.warning(f'Handled exception: \nfile://{file_path}')
-        except Exception as e:
-            raise OSError('Failed to save file while handling exception: \n' + str(e))
-        return None
+        return wrapper
 
-    return wrapper
+    return decorator
